==> ejc-jltest-api-3.0.0-20240321.002756-92-sources.jar: com/ejianc/business/jltest/margin/vo/InspiritLossDetailVO.java <==
package com.ejianc.business.jltest.margin.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 激励补亏分配详情明细
 * 
 * @author generator
 * 
 */
public class InspiritLossDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String detailCode; // 员工明细编号
    private Long detailId; // 员工明细
    private String detailName; // 姓名
    private String detailRole; // 角色
    private String detailPhone; // 手机号
    private BigDecimal detailPay; //  应缴纳金额（万元）
    private BigDecimal detailPayed; //  实际已应缴纳金额（万元）
    private BigDecimal detailPercentage; //  实际纳金额占比
    private BigDecimal detailAssessment; //  分配金额（万元）
    private BigDecimal detailAssessPercent; //  分配金额占比
    private String memo; // 备注
    private Long inspiritId; // 分配表ID
    

    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    public Long getDetailId() {
        return detailId;
    }

    public void setDetailId(Long detailId) {
        this.detailId = detailId;
    }
    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    public String getDetailRole() {
        return detailRole;
    }

    public void setDetailRole(String detailRole) {
        this.detailRole = detailRole;
    }
    public String getDetailPhone() {
        return detailPhone;
    }

    public void setDetailPhone(String detailPhone) {
        this.detailPhone = detailPhone;
    }
    public BigDecimal getDetailPay() {
        return detailPay;
    }

    public void setDetailPay(BigDecimal detailPay) {
        this.detailPay = detailPay;
    }
    public BigDecimal getDetailPayed() {
        return detailPayed;
    }

    public void setDetailPayed(BigDecimal detailPayed) {
        this.detailPayed = detailPayed;
    }
    public BigDecimal getDetailPercentage() {
        return detailPercentage;
    }

    public void setDetailPercentage(BigDecimal detailPercentage) {
        this.detailPercentage = detailPercentage;
    }
    public BigDecimal getDetailAssessment() {
        return detailAssessment;
    }

    public void setDetailAssessment(BigDecimal detailAssessment) {
        this.detailAssessment = detailAssessment;
    }
    public BigDecimal getDetailAssessPercent() {
        return detailAssessPercent;
    }

    public void setDetailAssessPercent(BigDecimal detailAssessPercent) {
        this.detailAssessPercent = detailAssessPercent;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getInspiritId() {
        return inspiritId;
    }

    public void setInspiritId(Long inspiritId) {
        this.inspiritId = inspiritId;
    }
    
}

==> ejc-jltest-api-3.0.0-20240323.092015-109-sources.jar: com/ejianc/business/jltest/margin/vo/InspiritLossDetailVO.java <==
package com.ejianc.business.jltest.margin.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 激励补亏分配详情明细
 *
 * @author generator
 *
 */
public class InspiritLossDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String detailCode; // 员工明细编号
    private Long detailId; // 员工明细
    private String detailName; // 姓名
    private String detailRole; // 角色
    private String detailPhone; // 手机号
    private BigDecimal detailPay; //  应缴纳金额（万元）
    private BigDecimal detailPayed; //  实际已应缴纳金额（万元）
    private BigDecimal detailPercentage; //  实际纳金额占比
    private BigDecimal detailAssessment; //  分配金额（万元）
    private BigDecimal detailAssessPercent; //  分配金额占比
    private String memo; // 备注
    private Long inspiritId; // 分配表ID


    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    @ReferSerialTransfer(referCode = "direct-employee-detail")
    public Long getDetailId() {
        return detailId;
    }
    @ReferDeserialTransfer

    public void setDetailId(Long detailId) {
        this.detailId = detailId;
    }
    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    public String getDetailRole() {
        return detailRole;
    }

    public void setDetailRole(String detailRole) {
        this.detailRole = detailRole;
    }
    public String getDetailPhone() {
        return detailPhone;
    }

    public void setDetailPhone(String detailPhone) {
        this.detailPhone = detailPhone;
    }
    public BigDecimal getDetailPay() {
        return detailPay;
    }

    public void setDetailPay(BigDecimal detailPay) {
        this.detailPay = detailPay;
    }
    public BigDecimal getDetailPayed() {
        return detailPayed;
    }

    public void setDetailPayed(BigDecimal detailPayed) {
        this.detailPayed = detailPayed;
    }
    public BigDecimal getDetailPercentage() {
        return detailPercentage;
    }

    public void setDetailPercentage(BigDecimal detailPercentage) {
        this.detailPercentage = detailPercentage;
    }
    public BigDecimal getDetailAssessment() {
        return detailAssessment;
    }

    public void setDetailAssessment(BigDecimal detailAssessment) {
        this.detailAssessment = detailAssessment;
    }
    public BigDecimal getDetailAssessPercent() {
        return detailAssessPercent;
    }

    public void setDetailAssessPercent(BigDecimal detailAssessPercent) {
        this.detailAssessPercent = detailAssessPercent;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getInspiritId() {
        return inspiritId;
    }

    public void setInspiritId(Long inspiritId) {
        this.inspiritId = inspiritId;
    }

}
